==> openmw_0.48.0.orig.tar.gz: openmw-openmw-0.48.0/components/esm4/loadsndr.hpp <==
/*
  Copyright (C) 2020 cc9cii

  This software is provided 'as-is', without any express or implied
  warranty.  In no event will the authors be held liable for any damages
  arising from the use of this software.

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.

  cc9cii cc9c@iinet.net.au

  Much of the information on the data structures are based on the information
  from Tes4Mod:Mod_File_Format and Tes5Mod:File_Formats but also refined by
  trial & error.  See http://en.uesp.net/wiki for details.

*/
#ifndef ESM4_SNDR_H
#define ESM4_SNDR_H

#include <cstdint>
#include <string>

#include "formid.hpp"
#include "script.hpp" // TargetCondition

namespace ESM4
{
    class Reader;
    class Writer;

#pragma pack(push, 1)
    struct LoopInfo
    {
        std::uint16_t flags;
        std::uint8_t unknown;
        std::uint8_t rumble;
    };

    struct SoundInfo
    {
        std::int8_t frequencyAdjustment; // %, signed
        std::uint8_t frequencyVariance;  // %
        std::uint8_t priority;           // default 128
        std::uint8_t dBVriance;
        std::uint16_t staticAttenuation; // divide by 100 to get value in dB
    };
#pragma pack(pop)

    struct SoundReference
    {
        FormId mFormId;       // from the header
        std::uint32_t mFlags; // from the header, see enum type RecordFlag for details

        std::string mEditorId;

        FormId mSoundCategory; // SNCT
        FormId mSoundId; // another SNDR
        FormId mOutputModel; // SOPM

        std::string mSoundFile;
        LoopInfo mLoopInfo;
        SoundInfo mData;

        TargetCondition mTargetCondition;

        void load(ESM4::Reader& reader);
        //void save(ESM4::Writer& writer) const;

        //void blank();
    };
}

#endif // ESM4_SNDR_H

==> openmw_0.49.0.orig.tar.gz: openmw-openmw-0.49.0/components/esm4/loadsndr.hpp <==
/*
  Copyright (C) 2020 cc9cii

  This software is provided 'as-is', without any express or implied
  warranty.  In no event will the authors be held liable for any damages
  arising from the use of this software.

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.

  cc9cii cc9c@iinet.net.au

  Much of the information on the data structures are based on the information
  from Tes4Mod:Mod_File_Format and Tes5Mod:File_Formats but also refined by
  trial & error.  See http://en.uesp.net/wiki for details.

*/
#ifndef ESM4_SNDR_H
#define ESM4_SNDR_H

#include <cstdint>
#include <string>

#include "script.hpp" // TargetCondition
#include <components/esm/defs.hpp>
#include <components/esm/formid.hpp>

namespace ESM4
{
    class Reader;
    class Writer;

#pragma pack(push, 1)
    struct LoopInfo
    {
        std::uint16_t flags;
        std::uint8_t unknown;
        std::uint8_t rumble;
    };

    struct SoundInfo
    {
        std::int8_t frequencyAdjustment; // %, signed
        std::uint8_t frequencyVariance; // %
        std::uint8_t priority; // default 128
        std::uint8_t dBVriance;
        std::uint16_t staticAttenuation; // divide by 100 to get value in dB
    };
#pragma pack(pop)

    struct SoundReference
    {
        ESM::FormId mId; // from the header
        std::uint32_t mFlags; // from the header, see enum type RecordFlag for details

        std::string mEditorId;

        ESM::FormId mSoundCategory; // SNCT
        ESM::FormId mSoundId; // another SNDR
        ESM::FormId mOutputModel; // SOPM
        ESM::FormId mBaseDescriptor; // BNAM

        std::string mSoundFile;
        LoopInfo mLoopInfo;
        SoundInfo mData;

        TargetCondition mTargetCondition;

        void load(ESM4::Reader& reader);
        // void save(ESM4::Writer& writer) const;

        // void blank();
        static constexpr ESM::RecNameInts sRecordId = ESM::RecNameInts::REC_SNDR4;
    };
}

#endif // ESM4_SNDR_H
